@@ -34,9 +34,12 @@ typedef enum {
 	GTK_HTML_COMMAND_CUT_LINE,
 
 	GTK_HTML_COMMAND_INSERT_PARAGRAPH,
+	GTK_HTML_COMMAND_INSERT_TAB,
 	GTK_HTML_COMMAND_INSERT_RULE,
 	GTK_HTML_COMMAND_INSERT_RULE_PARAM,
 	GTK_HTML_COMMAND_INSERT_IMAGE_PARAM,
+	GTK_HTML_COMMAND_INSERT_TAB_OR_INDENT_MORE,
+	GTK_HTML_COMMAND_INSERT_TAB_OR_INDENT_MORE_OR_NEXT_CELL,
 
 	GTK_HTML_COMMAND_MAKE_LINK,
 	GTK_HTML_COMMAND_REMOVE_LINK,
@@ -45,7 +48,7 @@ typedef enum {
 	GTK_HTML_COMMAND_DELETE_BACK,
 	GTK_HTML_COMMAND_DELETE_BACK_OR_INDENT_DEC,
 
-	GTK_HTML_COMMAND_SET_MARK,
+	GTK_HTML_COMMAND_SELECTION_MODE,
 	GTK_HTML_COMMAND_DISABLE_SELECTION,
 
 	GTK_HTML_COMMAND_BOLD_ON,
@@ -82,6 +85,7 @@ typedef enum {
 	GTK_HTML_COMMAND_INDENT_ZERO,
 	GTK_HTML_COMMAND_INDENT_INC,
 	GTK_HTML_COMMAND_INDENT_DEC,
+	GTK_HTML_COMMAND_INDENT_DEC_OR_PREV_CELL,
 	GTK_HTML_COMMAND_INDENT_PARAGRAPH,
 
 	GTK_HTML_COMMAND_BREAK_AND_FILL_LINE,
@@ -110,6 +114,8 @@ typedef enum {
 	GTK_HTML_COMMAND_MODIFY_SELECTION_EOL,
 	GTK_HTML_COMMAND_MODIFY_SELECTION_BOD,
 	GTK_HTML_COMMAND_MODIFY_SELECTION_EOD,
+	GTK_HTML_COMMAND_MODIFY_SELECTION_PREV_WORD,
+	GTK_HTML_COMMAND_MODIFY_SELECTION_NEXT_WORD,
 
 	GTK_HTML_COMMAND_CAPITALIZE_WORD,
 	GTK_HTML_COMMAND_UPCASE_WORD,
@@ -166,6 +172,29 @@ typedef enum {
 
 	GTK_HTML_COMMAND_CURSOR_POSITION_SAVE,
 	GTK_HTML_COMMAND_CURSOR_POSITION_RESTORE,
+
+	GTK_HTML_COMMAND_CURSOR_BOD,
+	GTK_HTML_COMMAND_CURSOR_EOD,
+
+	GTK_HTML_COMMAND_BLOCK_REDRAW,
+	GTK_HTML_COMMAND_UNBLOCK_REDRAW,
+
+	GTK_HTML_COMMAND_ZOOM_IN,
+	GTK_HTML_COMMAND_ZOOM_OUT,
+	GTK_HTML_COMMAND_ZOOM_RESET,
+
+	GTK_HTML_COMMAND_TABLE_SPACING_INC,
+	GTK_HTML_COMMAND_TABLE_SPACING_DEC,
+	GTK_HTML_COMMAND_TABLE_SPACING_ZERO,
+
+	GTK_HTML_COMMAND_TABLE_PADDING_INC,
+	GTK_HTML_COMMAND_TABLE_PADDING_DEC,
+	GTK_HTML_COMMAND_TABLE_PADDING_ZERO,
+
+	GTK_HTML_COMMAND_DELETE_TABLE,
+	GTK_HTML_COMMAND_DELETE_TABLE_ROW,
+	GTK_HTML_COMMAND_DELETE_TABLE_COLUMN,
+	GTK_HTML_COMMAND_DELETE_TABLE_CELL_CONTENTS,
 } GtkHTMLCommandType;
 
 typedef enum {
